@@ -70,7 +70,8 @@ DataBackend = R6Class("DataBackend", cloneable = FALSE,
 
     #' @description
     #' Helper for print outputs.
-    format = function() {
+    #' @param ... (ignored).
+    format = function(...) {
       sprintf("<%s>", class(self)[1L])
     },
 
