@@ -81,4 +81,4 @@ LearnerRegrFeatureless = R6Class("LearnerRegrFeatureless", inherit = LearnerRegr
 )
 
 #' @include mlr_learners.R
-mlr_learners$add("regr.featureless", LearnerRegrFeatureless)
+mlr_learners$add("regr.featureless", function() LearnerRegrFeatureless$new())
