@@ -44,7 +44,7 @@ MeasureSimilarity = R6Class("MeasureSimilarity", inherit = Measure, cloneable =
   public = list(
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(id, param_set = ps(), range, minimize = NA, average = "macro", aggregator = NULL, properties = character(), predict_type = "response",
+    initialize = function(id, param_set = ps(), range, minimize = NA, average = "macro", aggregator = NULL, properties = character(), predict_type = NA_character_,
       predict_sets = "test", task_properties = character(), packages = character(), label = NA_character_, man = NA_character_) {
       super$initialize(id, task_type = NA_character_, param_set = param_set, range = range, minimize = minimize, average = "custom", aggregator = aggregator,
         properties = c("requires_model", properties), predict_type = predict_type, predict_sets = predict_sets,
