@@ -105,6 +105,10 @@ Task = R6Class("Task",
     #' Required for [convert_task()].
     extra_args = NULL,
 
+    #' @field mlr3_version (`package_version`)\cr
+    #' Package version of `mlr3` used to create the task.
+    mlr3_version = NULL,
+
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     #'
@@ -148,6 +152,7 @@ Task = R6Class("Task",
       private$.col_roles = named_list(mlr_reflections$task_col_roles[[task_type]], character())
       private$.col_roles$feature = setdiff(cn, self$backend$primary_key)
       self$extra_args = assert_list(extra_args, names = "unique")
+      self$mlr3_version = packageVersion("mlr3")
     },
 
     #' @description
@@ -158,7 +163,8 @@ Task = R6Class("Task",
 
     #' @description
     #' Helper for print outputs.
-    format = function() {
+    #' @param ... (ignored).
+    format = function(...) {
       sprintf("<%s:%s>", class(self)[1L], self$id)
     },
 
@@ -172,10 +178,10 @@ Task = R6Class("Task",
       roles = self$col_roles
       roles = roles[lengths(roles) > 0L]
 
-      # print additional columns are specified in reflections
+      # print additional columns as specified in reflections
       before = mlr_reflections$task_print_col_roles$before
       iwalk(before[before %in% names(roles)], function(role, str) {
-        catn(str_indent(sprintf("* %s:", str), role))
+        catn(str_indent(sprintf("* %s:", str), roles[[role]]))
       })
 
       catf(str_indent("* Target:", self$target_names))
@@ -195,7 +201,7 @@ Task = R6Class("Task",
       # print additional columns are specified in reflections
       after = mlr_reflections$task_print_col_roles$after
       iwalk(after[after %in% names(roles)], function(role, str) {
-        catn(str_indent(sprintf("* %s:", str), role))
+        catn(str_indent(sprintf("* %s:", str), roles[[role]]))
       })
     },
 
@@ -1095,7 +1101,7 @@ task_rm_backend = function(task) {
 
 
 #' @export
-rd_info.Task = function(obj, section) { # nolint
+rd_info.Task = function(obj, section, ...) { # nolint
   x = c("",
     sprintf("* Task type: %s", rd_format_string(obj$task_type)),
     sprintf("* Dimensions: %ix%i", obj$nrow, obj$ncol),
