@@ -73,7 +73,9 @@ assert_learner = function(learner, task = NULL, task_type = NULL, properties = c
   assert_class(learner, "Learner", .var.name = .var.name)
 
   task_type = task_type %??% task$task_type
-  if (!is.null(task_type) && task_type != learner$task_type) {
+  # check on class(learner) does not work with GraphLearner and AutoTuner
+  # check on learner$task_type does not work with TaskUnsupervised
+  if (!test_matching_task_type(task_type, learner, "learner")) {
     stopf("Learner '%s' must have task type '%s'", learner$id, task_type)
   }
 
@@ -87,6 +89,20 @@ assert_learner = function(learner, task = NULL, task_type = NULL, properties = c
   invisible(learner)
 }
 
+test_matching_task_type = function(task_type, object, class) {
+  if (is.null(task_type) || object$task_type == task_type) {
+    return(TRUE)
+  }
+
+  cl_task_type = fget(mlr_reflections$task_types, task_type, class, "type")
+  if (inherits(object, cl_task_type)) {
+    return(TRUE)
+  }
+
+  cl_object = fget(mlr_reflections$task_types, object$task_type, class, "type")
+  return(cl_task_type == cl_object)
+}
+
 
 #' @export
 #' @param learners (list of [Learner]).
@@ -100,8 +116,10 @@ assert_task_learner = function(task, learner, cols = NULL) {
   if (length(pars) > 0) {
     stopf("%s cannot be trained with TuneToken present in hyperparameter: %s", learner$format(), str_collapse(names(pars)))
   }
+  # check on class(learner) does not work with GraphLearner and AutoTuner
+  # check on learner$task_type does not work with TaskUnsupervised
 
-  if (task$task_type != learner$task_type) {
+  if (!test_matching_task_type(task$task_type, learner, "learner")) {
     stopf("Type '%s' of %s does not match type '%s' of %s",
       task$task_type, task$format(), learner$task_type, learner$format())
   }
@@ -132,6 +150,9 @@ assert_task_learner = function(task, learner, cols = NULL) {
 #' @export
 #' @rdname mlr_assertions
 assert_learnable = function(task, learner) {
+  if (task$task_type == "unsupervised") {
+    stopf("%s cannot be trained with %s", learner$format(), task$format())
+  }
   assert_task_learner(task, learner)
 }
 
@@ -149,9 +170,8 @@ assert_predictable = function(task, learner) {
 assert_measure = function(measure, task = NULL, learner = NULL, .var.name = vname(measure)) {
   assert_class(measure, "Measure", .var.name = .var.name)
 
-
   if (!is.null(task)) {
-    if (!is_scalar_na(measure$task_type) && measure$task_type != task$task_type) {
+    if (!is_scalar_na(measure$task_type) && !test_matching_task_type(task$task_type, measure, "measure")) {
       stopf("Measure '%s' is not compatible with type '%s' of task '%s'",
         measure$id, task$task_type, task$id)
     }
@@ -312,10 +332,3 @@ assert_row_sums = function(prob) {
     }
   }
 }
-
-assert_same_task_type = function(objs) {
-  task_types = unique(map_chr(objs, "task_type"))
-  if (length(task_types) > 1L) {
-    stopf("Multiple task types detected, but mixing types is not supported: %s", str_collapse(task_types))
-  }
-}
